"""rxnmapper initialization."""
__name__ = "rxnmapper"
__version__ = "0.2.0"  # managed by bump2version


from .core import RXNMapper  # noqa
